==> react-ui-library-0.7.20.tgz: package/src/stories/select-story.js <==
import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Box,
  Select,
  Pane,
  Content
} from '../components'

export default function selectStory (module) {
  storiesOf('Select', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={10}>
          <Content markdown>
{`
# Select

The Select component is a \`select\` element. Implement the \`<Box />\` component.

\`\`\`
<Select>
  <option value="grapefruit">Grapefruit</option>
  <option value="lime">Lime</option>
  <option value="coconut">Coconut</option>
  <option value="mango">Mango</option>
</Select>
\`\`\`

`}
          </Content>
          <Select>
            <option value='grapefruit'>Grapefruit</option>
            <option value='lime'>Lime</option>
            <option value='coconut'>Coconut</option>
            <option value='mango'>Mango</option>
          </Select>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <Select>
        <option value='grapefruit'>Grapefruit</option>
        <option value='lime'>Lime</option>
        <option value='coconut'>Coconut</option>
        <option value='mango'>Mango</option>
      </Select>
    ))
    .add('with spacing', () => (
      <Pane white>
        <Select marginX={3}>
          <option value='grapefruit'>Grapefruit</option>
          <option value='lime'>Lime</option>
          <option value='coconut'>Coconut</option>
          <option value='mango'>Mango</option>
        </Select>
      </Pane>
    ))
    .add('with width and centered', () => (
      <Pane white clearfix>
        <Select width='240px' marginX='auto' marginY={10}>
          <option value='grapefruit'>Grapefruit</option>
          <option value='lime'>Lime</option>
          <option value='coconut'>Coconut</option>
          <option value='mango'>Mango</option>
        </Select>
      </Pane>
    ))
}

==> react-ui-library-0.9.0.tgz: package/src/stories/select-story.js <==
import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Select,
  Pane,
  Content,
  theme
} from '../components'
const { minorScale, majorScale } = theme

export default function selectStory (module) {
  storiesOf('Select', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
{`
# Select

The Select component is a \`select\` element. Implement the \`<Box />\` component.

\`\`\`
<Select>
  <option value="grapefruit">Grapefruit</option>
  <option value="lime">Lime</option>
  <option value="coconut">Coconut</option>
  <option value="mango">Mango</option>
</Select>
\`\`\`

`}
          </Content>
          <Select>
            <option value='grapefruit'>Grapefruit</option>
            <option value='lime'>Lime</option>
            <option value='coconut'>Coconut</option>
            <option value='mango'>Mango</option>
          </Select>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <Select>
        <option value='grapefruit'>Grapefruit</option>
        <option value='lime'>Lime</option>
        <option value='coconut'>Coconut</option>
        <option value='mango'>Mango</option>
      </Select>
    ))
    .add('with spacing', () => (
      <Pane white>
        <Select marginX={3}>
          <option value='grapefruit'>Grapefruit</option>
          <option value='lime'>Lime</option>
          <option value='coconut'>Coconut</option>
          <option value='mango'>Mango</option>
        </Select>
      </Pane>
    ))
    .add('with width and centered', () => (
      <Pane white clearfix>
        <Select width='240px' marginX='auto' marginY={majorScale(10)}>
          <option value='grapefruit'>Grapefruit</option>
          <option value='lime'>Lime</option>
          <option value='coconut'>Coconut</option>
          <option value='mango'>Mango</option>
        </Select>
      </Pane>
    ))
}
